@@ -31,15 +31,22 @@ class Control(object):
         for row in self.implementation_table.rows:
             if "Part" in row.cells[0].text and len(row.cells[0].text) < 8:
                 self.parts.append(row.cells[0].text.replace('Part ', '').strip())
-            elif len(self.parts) < 1 and len(self.implementation_table.rows) < 3:
-                self.parts.append(None)
+            elif 'Req.' in row.cells[0].text and len(row.cells[0].text) < 8:
+                self.parts.append(row.cells[0].text.replace('Req. ', '').strip())
+
+        if len(self.parts) < 1 and len(self.implementation_table.rows) < 3:
+            self.parts.append(None)
 
     def part(self, part_id):
         """
         Takes string part_id and returns corresponding implementation cell object.
         """
         if part_id == None:
-            return self.implementation_table.cell(1,0)
+            try:
+                return self.implementation_table.cell(1,0)
+            except IndexError:
+                raise IndexError('Control table %s does not have enough rows to contain a control response.' % (self.number))
+
         if part_id in self.parts:
             split_alpha_part = re.compile(r'\w\d')
             if split_alpha_part.match(part_id):
@@ -50,7 +57,10 @@ class Control(object):
                 except:
                     ValueError('Control does not have part ' + part_id)
             else:
-                return self.implementation_table.cell(self.LETTERS[part_id], 1)
+                try:
+                    return self.implementation_table.cell(self.LETTERS[part_id], 1)
+                except KeyError:
+                    return self.implementation_table.cell(int(part_id), 1)
         else:
             raise ValueError('Control does not have part ' + part_id)
 
@@ -86,6 +96,19 @@ class Control(object):
                     self.implementation_status.append('Alternative Implementation')
                 elif 'Not' in implementation_status:
                     self.implementation_status.append('Not Applicable')
+            elif '<w:checked/>\n' in p.xml or '<w:default w:val="1"/>' in p.xml:
+                #old style of checkboxes...
+                implementation_status = paragraph.text.strip()
+                if 'Partially' in implementation_status:
+                    self.implementation_status.append('Partially Implemented')
+                elif 'Implemented' in implementation_status:
+                    self.implementation_status.append('Implemented')
+                elif 'Planned' in implementation_status:
+                    self.implementation_status.append('Planned')
+                elif 'Alternative' in implementation_status:
+                    self.implementation_status.append('Alternative Implementation')
+                elif 'Not' in implementation_status:
+                    self.implementation_status.append('Not Applicable')
 
     def get_control_origination(self, cell):
         """
@@ -97,6 +120,26 @@ class Control(object):
             if 'w14:checked w14:val="1"' in p.xml:
                 xpath_elements = p.xpath('.//w:t')
                 control_origination = xpath_elements[len(xpath_elements)-1].text.strip()
+                if not control_origination:
+                    control_origination = xpath_elements[len(xpath_elements)-2].text.strip() #TODO: this is really ugly, but had to be done because inherited checkboxes werent being captured.
+                if "Service Provider Corporate" in control_origination:
+                    self.control_origination.append("Service Provider Corporate")
+                elif "Service Provider System Specific" in control_origination:
+                    self.control_origination.append("Service Provider System Specific")
+                elif "Hybrid" in control_origination:
+                    self.control_origination.append("Service Provider Hybrid")
+                elif "Configured" in control_origination:
+                    self.control_origination.append("Configured by Customer")
+                elif "Provided" in control_origination:
+                    self.control_origination.append("Provided by Customer")
+                elif "Shared" in control_origination:
+                    self.control_origination.append("Shared")
+                elif "Inherited" in control_origination:
+                    self.control_origination.append("Inherited")
+                elif "Not" in control_origination:
+                    self.control_origination.append("Not Applicable")
+            elif '<w:checked/>\n' in p.xml or '<w:default w:val="1"/>' in p.xml:
+                control_origination = paragraph.text.strip()
                 if "Service Provider Corporate" in control_origination:
                     self.control_origination.append("Service Provider Corporate")
                 elif "Service Provider System Specific" in control_origination:
